@@ -3,42 +3,47 @@ use LWP::UserAgent;
 use LWP::ConnCache;
 use Promises qw(deferred);
 use Try::Tiny;
-use Moo;
+use Moo 2;
 with 'Apache::Tika::Connection';
 
-use vars '$VERSION';
-$VERSION = '0.07';
+our $VERSION = '0.08';
 
 has ua => (
     is => 'ro',
-    #isa => 'Str',
-    default => sub { my $ua= LWP::UserAgent->new(); $ua->conn_cache( LWP::ConnCache->new ); $ua },
+    default => sub {
+        my $ua = LWP::UserAgent->new();
+        $ua->conn_cache( LWP::ConnCache->new );
+
+        $ua
+    },
 );
 
 sub request {
     my( $self, $method, $url, $content, @headers ) = @_;
-    # Should initialize
-    
+
     my $content_size = length $content;
-    
+    my @content = $content ? (Content => $content) : ();
+
     # 'text/plain' for the language
-    unshift @headers, "Content-Length" => $content_size;
-    my %headers= (($content
-               ? ('Content' => $content)
-               : ()),
-               @headers);
+    my %headers= (
+                  "Content-Length" => $content_size,
+                  "Accept"         => 'application/json,text/plain',
+                  'Content-Type'   => 'application/octet-stream',
+                  @headers,
+                  @content,
+                 );
     my $res = $self->ua->$method( $url, %headers);
-    
+
     my $p = deferred;
     my ( $code, $response ) = $self->process_response(
-        $res->request,                      # request
-        $res->code,    # code
-        $res->message,    # msg
-        $res->decoded_content,                        # body
+        $res->request,                     # request
+        $res->code,                        # code
+        $res->message,                     # msg
+        $res->decoded_content,             # body
         $res->headers                      # headers
     );
     $p->resolve( $code, $response );
-    
+
     $p->promise
 }
 
@@ -47,7 +52,7 @@ sub request {
 =head1 REPOSITORY
 
 The public repository of this module is
-L<https://github.com/Corion/apache-tika>.
+L<https://github.com/Corion/Apache-Tika-Async>.
 
 =head1 SUPPORT
 
@@ -66,7 +71,7 @@ Max Maischein C<corion@cpan.org>
 
 =head1 COPYRIGHT (c)
 
-Copyright 2014-2016 by Max Maischein C<corion@cpan.org>.
+Copyright 2014-2019 by Max Maischein C<corion@cpan.org>.
 
 =head1 LICENSE
 
